@@ -7,10 +7,10 @@
 
     .. _Devhelp: http://live.gnome.org/devhelp
 
-    :copyright: Copyright 2007-2014 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
-
+from __future__ import absolute_import
 
 import re
 from os import path
@@ -33,6 +33,7 @@ except ImportError:
 
 try:
     import gzip
+
     def comp_open(filename, mode='rb'):
         return gzip.open(filename + '.gz', mode)
 except ImportError:
@@ -81,7 +82,7 @@ class DevhelpBuilder(StandaloneHTMLBuilder):
 
         def write_toc(node, parent):
             if isinstance(node, addnodes.compact_paragraph) or \
-                   isinstance(node, nodes.bullet_list):
+               isinstance(node, nodes.bullet_list):
                 for subnode in node:
                     write_toc(subnode, parent)
             elif isinstance(node, nodes.list_item):
@@ -90,11 +91,11 @@ class DevhelpBuilder(StandaloneHTMLBuilder):
                     write_toc(subnode, item)
             elif isinstance(node, nodes.reference):
                 parent.attrib['link'] = node['refuri']
-                parent.attrib['name'] = node.astext().encode('utf-8')
+                parent.attrib['name'] = node.astext()
 
         def istoctree(node):
             return isinstance(node, addnodes.compact_paragraph) and \
-                   'toctree' in node
+                'toctree' in node
 
         for node in tocdoc.traverse(istoctree):
             write_toc(node, chapters)
@@ -128,6 +129,6 @@ class DevhelpBuilder(StandaloneHTMLBuilder):
         # Dump the XML file
         f = comp_open(path.join(outdir, outname + '.devhelp'), 'w')
         try:
-            tree.write(f)
+            tree.write(f, 'utf-8')
         finally:
             f.close()
