@@ -3,10 +3,11 @@
     sphinx.directives.other
     ~~~~~~~~~~~~~~~~~~~~~~~
 
-    :copyright: Copyright 2007-2014 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
+from six.moves import range
 from docutils import nodes
 from docutils.parsers.rst import Directive, directives
 from docutils.parsers.rst.directives.admonitions import BaseAdmonition
@@ -38,6 +39,8 @@ class TocTree(Directive):
     final_argument_whitespace = False
     option_spec = {
         'maxdepth': int,
+        'name': directives.unchanged,
+        'caption': directives.unchanged_required,
         'glob': directives.flag,
         'hidden': directives.flag,
         'includehidden': directives.flag,
@@ -47,8 +50,11 @@ class TocTree(Directive):
 
     def run(self):
         env = self.state.document.settings.env
-        suffix = env.config.source_suffix
+        suffixes = env.config.source_suffix
         glob = 'glob' in self.options
+        caption = self.options.get('caption')
+        if caption:
+            self.options.setdefault('name', nodes.fully_normalize_name(caption))
 
         ret = []
         # (title, ref) pairs, where ref may be a document, or an external link,
@@ -61,7 +67,18 @@ class TocTree(Directive):
         for entry in self.content:
             if not entry:
                 continue
-            if not glob:
+            if glob and ('*' in entry or '?' in entry or '[' in entry):
+                patname = docname_join(env.docname, entry)
+                docnames = sorted(patfilter(all_docnames, patname))
+                for docname in docnames:
+                    all_docnames.remove(docname)  # don't include it again
+                    entries.append((None, docname))
+                    includefiles.append(docname)
+                if not docnames:
+                    ret.append(self.state.document.reporter.warning(
+                        'toctree glob pattern %r didn\'t match any documents'
+                        % entry, line=self.lineno))
+            else:
                 # look for explicit titles ("Some Title <document>")
                 m = explicit_title_re.match(entry)
                 if m:
@@ -72,8 +89,10 @@ class TocTree(Directive):
                     ref = docname = entry
                     title = None
                 # remove suffixes (backwards compatibility)
-                if docname.endswith(suffix):
-                    docname = docname[:-len(suffix)]
+                for suffix in suffixes:
+                    if docname.endswith(suffix):
+                        docname = docname[:-len(suffix)]
+                        break
                 # absolutize filenames
                 docname = docname_join(env.docname, docname)
                 if url_re.match(ref) or ref == 'self':
@@ -84,19 +103,9 @@ class TocTree(Directive):
                         'document %r' % docname, line=self.lineno))
                     env.note_reread()
                 else:
+                    all_docnames.discard(docname)
                     entries.append((title, docname))
                     includefiles.append(docname)
-            else:
-                patname = docname_join(env.docname, entry)
-                docnames = sorted(patfilter(all_docnames, patname))
-                for docname in docnames:
-                    all_docnames.remove(docname) # don't include it again
-                    entries.append((None, docname))
-                    includefiles.append(docname)
-                if not docnames:
-                    ret.append(self.state.document.reporter.warning(
-                        'toctree glob pattern %r didn\'t match any documents'
-                        % entry, line=self.lineno))
         subnode = addnodes.toctree()
         subnode['parent'] = env.docname
         # entries contains all entries (self references, external links etc.)
@@ -104,6 +113,7 @@ class TocTree(Directive):
         # includefiles only entries that are documents
         subnode['includefiles'] = includefiles
         subnode['maxdepth'] = self.options.get('maxdepth', -1)
+        subnode['caption'] = caption
         subnode['glob'] = glob
         subnode['hidden'] = 'hidden' in self.options
         subnode['includehidden'] = 'includehidden' in self.options
@@ -112,6 +122,7 @@ class TocTree(Directive):
         set_source_info(self, subnode)
         wrappernode = nodes.compound(classes=['toctree-wrapper'])
         wrappernode.append(subnode)
+        self.add_name(wrappernode)
         ret.append(wrappernode)
         return ret
 
@@ -131,7 +142,7 @@ class Author(Directive):
         env = self.state.document.settings.env
         if not env.config.show_authors:
             return []
-        para = nodes.paragraph()
+        para = nodes.paragraph(translatable=False)
         emph = nodes.emphasis()
         para += emph
         if self.name == 'sectionauthor':
@@ -194,7 +205,7 @@ class VersionChange(Directive):
         if len(self.arguments) == 2:
             inodes, messages = self.state.inline_text(self.arguments[1],
                                                       self.lineno+1)
-            para = nodes.paragraph(self.arguments[1], '', *inodes)
+            para = nodes.paragraph(self.arguments[1], '', *inodes, translatable=False)
             set_source_info(self, para)
             node.append(para)
         else:
@@ -207,12 +218,14 @@ class VersionChange(Directive):
                 content.source = node[0].source
                 content.line = node[0].line
                 content += node[0].children
-                node[0].replace_self(nodes.paragraph('', '', content))
+                node[0].replace_self(nodes.paragraph('', '', content, translatable=False))
             node[0].insert(0, nodes.inline('', '%s: ' % text,
                                            classes=['versionmodified']))
         else:
             para = nodes.paragraph('', '',
-                nodes.inline('', '%s.' % text, classes=['versionmodified']))
+                                   nodes.inline('', '%s.' % text,
+                                                classes=['versionmodified']),
+                                   translatable=False)
             node.append(para)
         env = self.state.document.settings.env
         # XXX should record node.source as well
@@ -347,10 +360,10 @@ class Only(Directive):
             self.state.nested_parse(self.content, self.content_offset,
                                     node, match_titles=1)
             title_styles = self.state.memo.title_styles
-            if (not surrounding_title_styles
-                or not title_styles
-                or title_styles[0] not in surrounding_title_styles
-                or not self.state.parent):
+            if (not surrounding_title_styles or
+                    not title_styles or
+                    title_styles[0] not in surrounding_title_styles or
+                    not self.state.parent):
                 # No nested sections so no special handling needed.
                 return [node]
             # Calculate the depths of the current and nested sections.
