@@ -224,7 +224,7 @@ def make_termnodes_from_paragraph_node(env, node, new_id=None):
 
     termtext = node.astext()
     if new_id is None:
-        new_id = 'term-' + nodes.make_id(termtext)
+        new_id = nodes.make_id('term-' + termtext)
     if new_id in gloss_entries:
         new_id = 'term-' + str(len(gloss_entries))
     gloss_entries.add(new_id)
@@ -646,7 +646,12 @@ class StandardDomain(Domain):
             if target == fully_normalize_name(title):
                 title = env.config.numfig_format.get(figtype, '')
 
-            newtitle = title % '.'.join(map(str, fignumber))
+            try:
+                newtitle = title % '.'.join(map(str, fignumber))
+            except TypeError:
+                env.warn(fromdocname, 'invalid numfig_format: %s' % title)
+                return None
+
             return self.build_reference_node(fromdocname, builder,
                                              docname, labelid, newtitle,
                                              nodeclass=addnodes.number_reference,
