@@ -5,16 +5,41 @@
 
     Add links to module code in Python object descriptions.
 
-    :copyright: Copyright 2007-2014 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
+import traceback
+
+from six import iteritems, text_type
 from docutils import nodes
 
+import sphinx
 from sphinx import addnodes
 from sphinx.locale import _
 from sphinx.pycode import ModuleAnalyzer
+from sphinx.util import get_full_modname
 from sphinx.util.nodes import make_refnode
+from sphinx.util.console import blue
+
+
+def _get_full_modname(app, modname, attribute):
+    try:
+        return get_full_modname(modname, attribute)
+    except AttributeError:
+        # sphinx.ext.viewcode can't follow class instance attribute
+        # then AttributeError logging output only verbose mode.
+        app.verbose('Didn\'t find %s in %s' % (attribute, modname))
+        return None
+    except Exception as e:
+        # sphinx.ext.viewcode follow python domain directives.
+        # because of that, if there are no real modules exists that specified
+        # by py:function or other directives, viewcode emits a lot of warnings.
+        # It should be displayed only verbose mode.
+        app.verbose(traceback.format_exc().rstrip())
+        app.verbose('viewcode can\'t import %s, failed with error "%s"' %
+                    (modname, e))
+        return None
 
 
 def doctree_read(app, doctree):
@@ -22,24 +47,24 @@ def doctree_read(app, doctree):
     if not hasattr(env, '_viewcode_modules'):
         env._viewcode_modules = {}
 
-    def has_tag(modname, fullname, docname):
+    def has_tag(modname, fullname, docname, refname):
         entry = env._viewcode_modules.get(modname, None)
         try:
             analyzer = ModuleAnalyzer.for_module(modname)
         except Exception:
             env._viewcode_modules[modname] = False
             return
-        if not isinstance(analyzer.code, str):
+        if not isinstance(analyzer.code, text_type):
             code = analyzer.code.decode(analyzer.encoding)
         else:
             code = analyzer.code
         if entry is None or entry[0] != code:
             analyzer.find_tags()
-            entry = code, analyzer.tags, {}
+            entry = code, analyzer.tags, {}, refname
             env._viewcode_modules[modname] = entry
         elif entry is False:
             return
-        code, tags, used = entry
+        _, tags, used, _ = entry
         if fullname in tags:
             used[fullname] = docname
             return True
@@ -52,10 +77,14 @@ def doctree_read(app, doctree):
             if not isinstance(signode, addnodes.desc_signature):
                 continue
             modname = signode.get('module')
+            fullname = signode.get('fullname')
+            refname = modname
+            if env.config.viewcode_import:
+                modname = _get_full_modname(app, modname, fullname)
             if not modname:
                 continue
             fullname = signode.get('fullname')
-            if not has_tag(modname, fullname, env.docname):
+            if not has_tag(modname, fullname, env.docname, refname):
                 continue
             if fullname in names:
                 # only one link per name, please
@@ -72,6 +101,16 @@ def doctree_read(app, doctree):
             signode += onlynode
 
 
+def env_merge_info(app, env, docnames, other):
+    if not hasattr(other, '_viewcode_modules'):
+        return
+    # create a _viewcode_modules dict on the main environment
+    if not hasattr(env, '_viewcode_modules'):
+        env._viewcode_modules = {}
+    # now merge in the information from the subprocess
+    env._viewcode_modules.update(other._viewcode_modules)
+
+
 def missing_reference(app, env, node, contnode):
     # resolve our "viewcode" reference nodes -- they need special treatment
     if node['reftype'] == 'viewcode':
@@ -88,13 +127,15 @@ def collect_pages(app):
 
     modnames = set(env._viewcode_modules)
 
-    app.builder.info(' (%d module code pages)' %
-                     len(env._viewcode_modules), nonl=1)
+#    app.builder.info(' (%d module code pages)' %
+#                     len(env._viewcode_modules), nonl=1)
 
-    for modname, entry in env._viewcode_modules.items():
+    for modname, entry in app.status_iterator(
+            iteritems(env._viewcode_modules), 'highlighting module code... ',
+            blue, len(env._viewcode_modules), lambda x: x[0]):
         if not entry:
             continue
-        code, tags, used = entry
+        code, tags, used, refname = entry
         # construct a page name for the highlighted source
         pagename = '_modules/' + modname.replace('.', '/')
         # highlight the source using the builder's highlighter
@@ -109,13 +150,13 @@ def collect_pages(app):
         # the collected tags (HACK: this only works if the tag boundaries are
         # properly nested!)
         maxindex = len(lines) - 1
-        for name, docname in used.items():
+        for name, docname in iteritems(used):
             type, start, end = tags[name]
-            backlink = urito(pagename, docname) + '#' + modname + '.' + name
+            backlink = urito(pagename, docname) + '#' + refname + '.' + name
             lines[start] = (
                 '<div class="viewcode-block" id="%s"><a class="viewcode-back" '
-                'href="%s">%s</a>' % (name, backlink, _('[docs]'))
-                + lines[start])
+                'href="%s">%s</a>' % (name, backlink, _('[docs]')) +
+                lines[start])
             lines[min(end - 1, maxindex)] += '</div>'
         # try to find parents (for submodules)
         parents = []
@@ -134,15 +175,14 @@ def collect_pages(app):
         context = {
             'parents': parents,
             'title': modname,
-            'body': _('<h1>Source code for %s</h1>') % modname + \
-                    '\n'.join(lines)
+            'body': (_('<h1>Source code for %s</h1>') % modname +
+                     '\n'.join(lines)),
         }
         yield (pagename, context, 'page.html')
 
     if not modnames:
         return
 
-    app.builder.info(' _modules/index', nonl=True)
     html = ['\n']
     # the stack logic is needed for using nested lists for submodules
     stack = ['']
@@ -162,16 +202,19 @@ def collect_pages(app):
     html.append('</ul>' * (len(stack) - 1))
     context = {
         'title': _('Overview: module code'),
-        'body': _('<h1>All modules for which code is available</h1>') + \
-            ''.join(html),
+        'body': (_('<h1>All modules for which code is available</h1>') +
+                 ''.join(html)),
     }
 
     yield ('_modules/index', context, 'page.html')
 
 
 def setup(app):
+    app.add_config_value('viewcode_import', True, False)
     app.connect('doctree-read', doctree_read)
+    app.connect('env-merge-info', env_merge_info)
     app.connect('html-collect-pages', collect_pages)
     app.connect('missing-reference', missing_reference)
-    #app.add_config_value('viewcode_include_modules', [], 'env')
-    #app.add_config_value('viewcode_exclude_modules', [], 'env')
+    # app.add_config_value('viewcode_include_modules', [], 'env')
+    # app.add_config_value('viewcode_exclude_modules', [], 'env')
+    return {'version': sphinx.__display_version__, 'parallel_read_safe': True}
