@@ -5,11 +5,10 @@
 
     Highlight code blocks using Pygments.
 
-    :copyright: Copyright 2007-2014 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
-import sys
 import re
 import textwrap
 
@@ -19,56 +18,44 @@ except ImportError:
     # parser is not available on Jython
     parser = None
 
+from six import PY2, text_type
+
 from sphinx.util.pycompat import htmlescape
 from sphinx.util.texescape import tex_hl_escape_map_new
 from sphinx.ext import doctest
 
-try:
-    import pygments
-    from pygments import highlight
-    from pygments.lexers import PythonLexer, PythonConsoleLexer, CLexer, \
-         TextLexer, RstLexer
-    from pygments.lexers import get_lexer_by_name, guess_lexer
-    from pygments.formatters import HtmlFormatter, LatexFormatter
-    from pygments.filters import ErrorToken
-    from pygments.styles import get_style_by_name
-    from pygments.util import ClassNotFound
-    from sphinx.pygments_styles import SphinxStyle, NoneStyle
-except ImportError:
-    pygments = None
-    lexers = None
-    HtmlFormatter = LatexFormatter = None
-else:
+from pygments import highlight
+from pygments.lexers import PythonLexer, PythonConsoleLexer, CLexer, \
+    TextLexer, RstLexer
+from pygments.lexers import get_lexer_by_name, guess_lexer
+from pygments.formatters import HtmlFormatter, LatexFormatter
+from pygments.filters import ErrorToken
+from pygments.styles import get_style_by_name
+from pygments.util import ClassNotFound
+from sphinx.pygments_styles import SphinxStyle, NoneStyle
 
-    lexers = dict(
-        none = TextLexer(),
-        python = PythonLexer(),
-        pycon = PythonConsoleLexer(),
-        pycon3 = PythonConsoleLexer(python3=True),
-        rest = RstLexer(),
-        c = CLexer(),
-    )
-    for _lexer in list(lexers.values()):
-        _lexer.add_filter('raiseonerror')
+lexers = dict(
+    none = TextLexer(stripnl=False),
+    python = PythonLexer(stripnl=False),
+    pycon = PythonConsoleLexer(stripnl=False),
+    pycon3 = PythonConsoleLexer(python3=True, stripnl=False),
+    rest = RstLexer(stripnl=False),
+    c = CLexer(stripnl=False),
+)
+for _lexer in lexers.values():
+    _lexer.add_filter('raiseonerror')
 
 
-escape_hl_chars = {ord('\\'): '\\PYGZbs{}',
-                   ord('{'): '\\PYGZob{}',
-                   ord('}'): '\\PYGZcb{}'}
+escape_hl_chars = {ord(u'\\'): u'\\PYGZbs{}',
+                   ord(u'{'): u'\\PYGZob{}',
+                   ord(u'}'): u'\\PYGZcb{}'}
 
-# used if Pygments is not available
-_LATEX_STYLES = r'''
-\newcommand\PYGZbs{\char`\\}
-\newcommand\PYGZob{\char`\{}
-\newcommand\PYGZcb{\char`\}}
+# used if Pygments is available
+# use textcomp quote to get a true single quote
+_LATEX_ADD_STYLES = r'''
+\renewcommand\PYGZsq{\textquotesingle}
 '''
 
-parsing_exceptions = (SyntaxError, UnicodeEncodeError)
-if sys.version_info < (2, 5):
-    # Python <= 2.4 raises MemoryError when parsing an
-    # invalid encoding cookie
-    parsing_exceptions += MemoryError,
-
 
 class PygmentsBridge(object):
     # Set these attributes if you want to have different Pygments formatters
@@ -79,8 +66,6 @@ class PygmentsBridge(object):
     def __init__(self, dest='html', stylename='sphinx',
                  trim_doctest_flags=False):
         self.dest = dest
-        if not pygments:
-            return
         if stylename is None or stylename == 'sphinx':
             style = SphinxStyle
         elif stylename == 'none':
@@ -92,7 +77,7 @@ class PygmentsBridge(object):
         else:
             style = get_style_by_name(stylename)
         self.trim_doctest_flags = trim_doctest_flags
-        self.formatter_args = {'style' : style}
+        self.formatter_args = {'style': style}
         if dest == 'html':
             self.formatter = self.html_formatter
         else:
@@ -129,13 +114,9 @@ class PygmentsBridge(object):
         src = src.replace("...", mark)
 
         # lines beginning with "..." are probably placeholders for suite
-        src = re.sub(r"(?m)^(\s*)" + mark + "(.)", r"\1"+ mark + r"# \2", src)
+        src = re.sub(r"(?m)^(\s*)" + mark + "(.)", r"\1" + mark + r"# \2", src)
 
-        # if we're using 2.5, use the with statement
-        if sys.version_info >= (2, 5):
-            src = 'from __future__ import with_statement\n' + src
-
-        if sys.version_info < (3, 0) and isinstance(src, str):
+        if PY2 and isinstance(src, text_type):
             # Non-ASCII chars will only occur in string literals
             # and comments.  If we wanted to give them to the parser
             # correctly, we'd have to find out the correct source
@@ -143,27 +124,19 @@ class PygmentsBridge(object):
             # just replace all non-ASCII characters.
             src = src.encode('ascii', 'replace')
 
-        if (3, 0) <= sys.version_info < (3, 2):
-            # Python 3.1 can't process '\r' as linesep.
-            # `parser.suite("print('hello')\r\n")` cause error.
-            if '\r\n' in src:
-                src = src.replace('\r\n', '\n')
-
         if parser is None:
             return True
 
         try:
             parser.suite(src)
-        except parsing_exceptions:
+        except (SyntaxError, UnicodeEncodeError):
             return False
         else:
             return True
 
-    def highlight_block(self, source, lang, warn=None, force=False, **kwargs):
-        if not isinstance(source, str):
+    def highlight_block(self, source, lang, opts=None, warn=None, force=False, **kwargs):
+        if not isinstance(source, text_type):
             source = source.decode()
-        if not pygments:
-            return self.unhighlighted(source)
 
         # find out which lexer to use
         if lang in ('py', 'python'):
@@ -191,7 +164,7 @@ class PygmentsBridge(object):
                 lexer = lexers[lang]
             else:
                 try:
-                    lexer = lexers[lang] = get_lexer_by_name(lang)
+                    lexer = lexers[lang] = get_lexer_by_name(lang, **opts or {})
                 except ClassNotFound:
                     if warn:
                         warn('Pygments lexer name %r is not known' % lang)
@@ -217,18 +190,13 @@ class PygmentsBridge(object):
         if self.dest == 'html':
             return hlsource
         else:
-            if not isinstance(hlsource, str):  # Py2 / Pygments < 1.6
+            if not isinstance(hlsource, text_type):  # Py2 / Pygments < 1.6
                 hlsource = hlsource.decode()
             return hlsource.translate(tex_hl_escape_map_new)
 
     def get_stylesheet(self):
-        if not pygments:
-            if self.dest == 'latex':
-                return _LATEX_STYLES
-            # no HTML styles needed
-            return ''
         formatter = self.get_formatter()
         if self.dest == 'html':
             return formatter.get_style_defs('.highlight')
         else:
-            return formatter.get_style_defs()
+            return formatter.get_style_defs() + _LATEX_ADD_STYLES
