@@ -5,15 +5,16 @@
 
     Glue code for the jinja2 templating engine.
 
-    :copyright: Copyright 2007-2014 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
 from os import path
 from pprint import pformat
 
+from six import string_types
 from jinja2 import FileSystemLoader, BaseLoader, TemplateNotFound, \
-     contextfunction
+    contextfunction
 from jinja2.utils import open_if_exists
 from jinja2.sandbox import SandboxedEnvironment
 
@@ -22,16 +23,18 @@ from sphinx.util.osutil import mtimes_of_files
 
 
 def _tobool(val):
-    if isinstance(val, str):
+    if isinstance(val, string_types):
         return val.lower() in ('true', '1', 'yes', 'on')
     return bool(val)
 
+
 def _toint(val):
     try:
         return int(val)
     except ValueError:
         return 0
 
+
 def accesskey(context, key):
     """Helper to output each access key only once."""
     if '_accesskeys' not in context:
@@ -41,11 +44,14 @@ def accesskey(context, key):
         return 'accesskey="%s"' % key
     return ''
 
+
 class idgen(object):
     def __init__(self):
         self.id = 0
+
     def current(self):
         return self.id
+
     def __next__(self):
         self.id += 1
         return self.id
@@ -70,6 +76,7 @@ class SphinxFileSystemLoader(FileSystemLoader):
                 f.close()
 
             mtime = path.getmtime(filename)
+
             def uptodate():
                 try:
                     return path.getmtime(filename) == mtime
@@ -79,7 +86,6 @@ class SphinxFileSystemLoader(FileSystemLoader):
         raise TemplateNotFound(template)
 
 
-
 class BuiltinTemplateLoader(TemplateBridge, BaseLoader):
     """
     Interfaces the rendering environment of jinja2 for use in Sphinx.
@@ -113,7 +119,7 @@ class BuiltinTemplateLoader(TemplateBridge, BaseLoader):
         self.pathchain = pathchain
 
         # make the paths into loaders
-        self.loaders = list(map(SphinxFileSystemLoader, loaderchain))
+        self.loaders = [SphinxFileSystemLoader(x) for x in loaderchain]
 
         use_i18n = builder.app.translator is not None
         extensions = use_i18n and ['jinja2.ext.i18n'] or []
