@@ -349,8 +349,9 @@ class HTMLTranslator(BaseTranslator):
         if isinstance(node.parent, nodes.container) and node.parent.get('literal_block'):
             self.add_permalink_ref(node.parent, _('Permalink to this code'))
         elif isinstance(node.parent, nodes.figure):
-            self.add_permalink_ref(
-                node.parent.traverse(nodes.image)[0], _('Permalink to this image'))
+            image_nodes = node.parent.traverse(nodes.image)
+            target_node = image_nodes and image_nodes[0] or node.parent
+            self.add_permalink_ref(target_node, _('Permalink to this image'))
         elif node.parent.get('toctree'):
             self.add_permalink_ref(node.parent.parent, _('Permalink to this toctree'))
 
