@@ -303,8 +303,6 @@ class TextTranslator(nodes.NodeVisitor):
 
     def visit_desc_signature(self, node):
         self.new_state(0)
-        if node.parent['objtype'] in ('class', 'exception'):
-            self.add_text('%s ' % node.parent['objtype'])
 
     def depart_desc_signature(self, node):
         # XXX: wrap signatures in a way that makes sense
@@ -630,8 +628,7 @@ class TextTranslator(nodes.NodeVisitor):
             self.end_state(first='%s. ' % self.list_counter[-1])
 
     def visit_definition_list_item(self, node):
-        self._li_has_classifier = len(node) >= 2 and \
-            isinstance(node[1], nodes.classifier)
+        self._classifier_count_in_li = len(node.traverse(nodes.classifier))
 
     def depart_definition_list_item(self, node):
         pass
@@ -640,7 +637,7 @@ class TextTranslator(nodes.NodeVisitor):
         self.new_state(0)
 
     def depart_term(self, node):
-        if not self._li_has_classifier:
+        if not self._classifier_count_in_li:
             self.end_state(end=None)
 
     def visit_termsep(self, node):
@@ -651,7 +648,9 @@ class TextTranslator(nodes.NodeVisitor):
         self.add_text(' : ')
 
     def depart_classifier(self, node):
-        self.end_state(end=None)
+        self._classifier_count_in_li -= 1
+        if not self._classifier_count_in_li:
+            self.end_state(end=None)
 
     def visit_definition(self, node):
         self.new_state()
@@ -711,6 +710,9 @@ class TextTranslator(nodes.NodeVisitor):
     def _visit_admonition(self, node):
         self.new_state(2)
 
+        if isinstance(node.children[0], nodes.Sequential):
+            self.add_text(self.nl)
+
     def _make_depart_admonition(name):
         def depart_admonition(self, node):
             self.end_state(first=admonitionlabels[name] + ': ')
